/* $NetBSD$ */

/*
 * File "cd_sessions.c" is part of the UDFclient toolkit.
 * File $Id: cd_sessions.c,v 1.21 2003/09/14 14:18:58 imago Exp $ $Name: release-ro1 $
 *
 * Copyright (c) 2003 Reinoud Zandijk <reinoud@netbsd.org>
 * All rights reserved.
 *
 * The UDFclient toolkit is distributed under the Clarified Artistic Licence.
 * A copy of the licence is included in the distribution as
 * `LICENCE.clearified.artistic' and a copy of the licence can also be
 * requested at the GNU foundantion's website.
 *
 * Visit the UDFclient toolkit homepage http://www.13thmonkey.org/udfclient/
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */


#include <stdio.h>
#include <fcntl.h>
#include <unistd.h>
#include <stdlib.h>
#include <errno.h>
#include <strings.h>
#include <assert.h>
#include <sys/types.h>

#include "udf.h"
#include "udf_bswap.h"


struct udf_discinfo *disc;
extern int udf_verbose;
extern int scsilib_verbose;


int main(int argc, char **argv) {
	char *dev_name;
	int   session;

	dev_name = argv[1];
	if (!dev_name) {
		printf("Usage : %s devicename\n", argv[0]);
		return 1;
	};

	udf_verbose     = UDF_VERBLEV_ACTIONS;
	udf_verbose     = UDF_VERBLEV_MAX;
	scsilib_verbose = 0;

	printf("Opening device %s\n", dev_name);
	errno = udf_open_disc(dev_name, &disc);
	if (errno) {
		perror("aborting ");
		exit(1);
	};

	printf("Disc info :\n" );
	printf("\tMMC profile        : 0x%02x\n", disc->mmc_profile);
	printf("\trecordable         : %s\n", disc->recordable ?"yes":" no");
	printf("\trewritable         : %s\n", disc->rewritable?"yes":" no");
	printf("\tdisc state         : %d\n", disc->disc_state);
	printf("\tlast session state : %d\n", disc->last_session_state);
	printf("\tNumber of sessions     %d\n", disc->num_sessions);
	for(session = 0; session < disc->num_sessions; session++) {
		printf("\tSession %d\n", session);
		printf("\t\tstart  at         %d\n", (uint32_t) disc->session_start[session]);
		printf("\t\tends   at         %d\n", (uint32_t) disc->session_end[session]);
		printf("\t\tlength for        %d\n", (uint32_t) (disc->session_end[session] - disc->session_start[session]));
		printf("\t\tnext writable at  %d\n", disc->next_writable[session]);
		printf("\t\tfree blocks       %d\n", disc->free_blocks[session]);
		printf("\t\tpacket size       %d\n", disc->packet_size[session]);
		printf("\n");
	};

	udf_close_disc(disc);

	return 0;
};

